//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/LayerItem.h
//! @brief     Defines class LayerItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_LAYERITEM_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_LAYERITEM_H

#include "GUI/Model/Group/SelectionDescriptor.h"
#include "GUI/Model/Sample/ItemWithMaterial.h"
#include "GUI/Model/Sample/LayerRoughnessItems.h"
#include <QColor>
#include <QUuid>
#include <QVector>
#include <memory>
#include <variant>

class LayerBasicRoughnessItem;
class ParticleLayoutItem;
class UIntDescriptor;
class DoubleDescriptor;
class ItemWithParticles;
class QXmlStreamReader;
class QXmlStreamWriter;

class LayerItem : public ItemWithMaterial {
public:
    LayerItem();

    void setLayerName(const QString& name);
    QString layerName() const;

    QVector<ItemWithMaterial*> itemsWithMaterial();
    QVector<ItemWithParticles*> itemsWithParticles() const;

    DoubleDescriptor thickness() const;

    SelectionDescriptor<LayerBasicRoughnessItem*> roughness();
    void setBasicRoughness();
    void clearRoughness();

    UIntDescriptor numSlices() const;

    QVector<ParticleLayoutItem*> layouts() const;
    ParticleLayoutItem* addLayout();
    void removeLayout(ParticleLayoutItem* layout);

    QColor color() const;
    void setColor(const QColor& color);

    void setIsTopLayer(bool b);
    bool isTopLayer() const;

    void setIsBottomLayer(bool b);
    bool isBottomLayer() const;

    void writeContentTo(QXmlStreamWriter* writer) const;
    void readContentFrom(QXmlStreamReader* reader);

private:
    //! Returns a unique identifier for descriptors.
    //!
    //! lastPart will be attached to identify the relevant descriptor.
    QString uidForDescriptor(const QString& lastPart) const;

private:
    QUuid m_uid;
    QString m_name;
    uint m_numSlices;
    double m_thickness;
    QColor m_color;
    bool m_isTopLayer = false;
    bool m_isBottomLayer = false;
    QVector<ParticleLayoutItem*> m_layouts;
    std::unique_ptr<LayerBasicRoughnessItem> m_topRoughness;
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_LAYERITEM_H
