//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/LayerRoughnessItems.cpp
//! @brief     Implements classes LayerRoughnessItems
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Sample/LayerRoughnessItems.h"
#include "GUI/Model/Session/SessionXML.h"
#include "GUI/Model/Types/DoubleDescriptor.h"

using namespace GUI::Session::XML;

namespace {

namespace Tags {
const QString Uid("Uid");
} // namespace Tags
} // namespace

LayerBasicRoughnessItem::LayerBasicRoughnessItem()
{
    m_uid = QUuid::createUuid();
}

DoubleDescriptor LayerBasicRoughnessItem::sigma() const
{
    DoubleDescriptor d("Sigma", &m_sigma, Unit::nanometer);
    d.tooltip = "rms of the roughness";
    d.path = [=]() { return "roughness/" + m_uid.toString() + "/sigma"; };
    return d;
}

DoubleDescriptor LayerBasicRoughnessItem::hurst() const
{
    DoubleDescriptor d("Hurst", &m_hurst, Unit::unitless);
    d.tooltip = "Hurst parameter which describes how jagged the interface,\n "
                "dimensionless [0.0, 1.0], where 0.0 gives more spikes, \n1.0 more smoothness.";
    d.limits = RealLimits::limited(0.0, 1.0);
    d.path = [=]() { return "roughness/" + m_uid.toString() + "/hurst"; };
    return d;
}

DoubleDescriptor LayerBasicRoughnessItem::lateralCorrelationLength() const
{
    DoubleDescriptor d("Correlation length", &m_lateralCorrelationLength, Unit::nanometer);
    d.tooltip = "Lateral correlation length of the roughness";
    d.path = [=]() { return "roughness/" + m_uid.toString() + "/corrLen"; };
    return d;
}

void LayerBasicRoughnessItem::writeContentTo(QXmlStreamWriter* writer) const
{
    writeAttribute(writer, GUI::Session::XML::Version, int(1));
    writeAttribute(writer, Tags::Uid, m_uid.toString());
    writeDescriptors(writer, {sigma(), hurst(), lateralCorrelationLength()});
}

void LayerBasicRoughnessItem::readContentFrom(QXmlStreamReader* reader)
{
    // #baMigration ++ implement
}
