//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/LayerRoughnessItems.h
//! @brief     Defines classes LayerRoughnessItems
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_SAMPLE_LAYERROUGHNESSITEMS_H
#define BORNAGAIN_GUI_MODEL_SAMPLE_LAYERROUGHNESSITEMS_H

#include "GUI/Model/Session/SessionItem.h"
#include <QUuid>

class DoubleDescriptor;
class QXmlStreamReader;
class QXmlStreamWriter;

class LayerBasicRoughnessItem {
public:
    LayerBasicRoughnessItem();
    DoubleDescriptor sigma() const;
    DoubleDescriptor hurst() const;
    DoubleDescriptor lateralCorrelationLength() const;

    void writeContentTo(QXmlStreamWriter* writer) const;
    void readContentFrom(QXmlStreamReader* reader);

private:
    QUuid m_uid;
    double m_sigma = 1.0;
    double m_hurst = 0.3;
    double m_lateralCorrelationLength = 5.0;
};

#endif // BORNAGAIN_GUI_MODEL_SAMPLE_LAYERROUGHNESSITEMS_H
