//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Sample/SampleModel.cpp
//! @brief     Implements class SampleModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Sample/SampleModel.h"
#include "GUI/Model/Group/PropertyItem.h"
#include "GUI/Model/Sample/ItemWithMaterial.h"
#include "GUI/Model/Sample/MultiLayerItem.h"
#include "GUI/Model/Session/ModelPath.h"
#include "GUI/Model/Session/SessionXML.h"
#include <QApplication>
#include <QFontMetrics>
#include <QPixmap>
#include <QXmlStreamWriter>

using namespace GUI::Session::XML;


SampleModel::SampleModel() {}

QVector<MultiLayerItem*> SampleModel::multiLayerItems() const
{
    return m_multiLayers;
}

QVector<ItemWithMaterial*> SampleModel::itemsWithMaterial() const
{
    QVector<ItemWithMaterial*> result;

    for (auto* m : m_multiLayers)
        result << m->itemsWithMaterial();

    return result;
}

MultiLayerItem* SampleModel::addMultiLayer()
{
    m_multiLayers << new MultiLayerItem();
    return m_multiLayers.back();
}

void SampleModel::removeMultiLayer(MultiLayerItem* item)
{
    m_multiLayers.removeAll(item);
}

QStringList SampleModel::multiLayerNames() const
{
    QStringList existingNames;
    for (const auto* item : m_multiLayers)
        existingNames << item->sampleName();
    return existingNames;
}

void SampleModel::writeContentTo(QXmlStreamWriter* writer) const
{
    writeAttribute(writer, GUI::Session::XML::Version, int(1));
    for (auto* m : m_multiLayers) {
        writer->writeStartElement("MultiLayer");
        m->writeContentTo(writer);
        writer->writeEndElement();
    }
}

void SampleModel::readContentFrom(QXmlStreamReader* reader)
{
    // #baMigration ++ implement
}
