//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Types/UIntProperty.cpp
//! @brief     Implements class UIntProperty
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Types/UIntProperty.h"
#include <QUuid>

void UIntProperty::init(const QString& label, const QString& tooltip, uint value,
                        const variant<QString, Unit>& unit, const QString& persistentTag)
{
    init(label, tooltip, value, unit, RealLimits::nonnegative(), persistentTag);
}

void UIntProperty::init(const QString& label, const QString& tooltip, uint value,
                        const variant<QString, Unit>& unit, const RealLimits& limits,
                        const QString& persistentTag)
{
    m_value = value;
    m_persistentTag = persistentTag;
    m_uid = QUuid::createUuid().toString();

    m_descriptor.label = label;
    m_descriptor.tooltip = tooltip;
    m_descriptor.limits = limits;
    m_descriptor.unit = unit;
    m_descriptor.set = [=](double v) { m_value = v; };
    m_descriptor.get = [=] { return m_value; };
    m_descriptor.path = [=] { return m_uid; };
}
