//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorBox.h
//! @brief     Defines class FormFactorBox.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORBOX_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORBOX_H

#include "Sample/HardParticle/IFormFactorPrism.h"

//! A rectangular prism (parallelepiped).
//! @ingroup hardParticle

class FormFactorBox : public IFormFactorPrism {
public:
    std::string className() const final { return "FormFactorBox"; }

    FormFactorBox(std::vector<double> P);
    FormFactorBox(double length, double width, double height);

    FormFactorBox* clone() const override { return new FormFactorBox(m_length, m_width, m_height); }

    double length() const { return m_length; }
    double width() const { return m_width; }
    double height() const override { return m_height; }

    double volume() const override { return m_length * m_height * m_width; }
    double radialExtension() const override { return m_length / 2.0; }
    complex_t formfactor(C3 q) const override;

private:
    const double& m_length;
    const double& m_width;
    const double& m_height;
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORBOX_H
